The purpose of this crate is to offer a single source of truth for the definitions of shared constants within the codebase. This is useful because many different components within Aptos often require access to global constant definitions (e.g., Safety Rules, Key Manager, and Secure Storage). To avoid duplicating these definitions across crates (and better allow these constants to be updated in a single location), we define them here.
Constants
- APTOS_
ROOT_ KEY - Definitions of global cryptographic keys (e.g., as held in secure storage)
- CONSENSUS_
KEY - FULLNODE_
NETWORK_ KEY - GAS_
HEADROOM_ DENOMINATOR - GAS_
HEADROOM_ NUMERATOR - GAS_
UNIT_ PRICE - GENESIS_
WAYPOINT - MAX_
GAS_ AMOUNT - MIN_
PRICE_ PER_ GAS_ UNIT - MOVE_
MODULES - OPERATOR_
ACCOUNT - OPERATOR_
KEY - OWNER_
ACCOUNT - OWNER_
KEY - SAFETY_
DATA - Definitions of global data items (e.g., as held in secure storage)
- VALIDATOR_
NETWORK_ KEY - WAYPOINT
Functions
- adjust_
gas_ headroom - Gas costs are dynamic based on storage, so the simulation values need some headroom applied by the user if using it to estimate gas